@@ -1,8 +1,8 @@
 #' End-user-ready results for network meta-regression
 #'
 #' @description Illustrates the effect estimates, predictions and regression
-#'   coefficients of comparisons with a specified comparator intervention
-#'   and also exports these results to an Excel file.
+#'   coefficients of comparisons with a specified comparator intervention for a
+#'   selected covariate value and also exports these results to an Excel file.
 #'
 #' @param full An object of S3 class \code{\link{run_model}}. See 'Value' in
 #'   \code{\link{run_model}}.
@@ -51,8 +51,8 @@
 #'   \item{interval_plot}{A forest plot on the estimated and predicted effect
 #'   sizes of comparisons with the selected comparator intervention under
 #'   network meta-analysis and network meta-regression based on the specified
-#'   \code{cov_value}. See 'Details' and 'Value' in
-#'   \code{\link{forestplot_metareg}}.}
+#'   \code{cov_value} alongside a forest plot with the corresponding SUCRA
+#'   values. See 'Details' and 'Value' in \code{\link{forestplot_metareg}}.}
 #'   \item{sucra_scatterplot}{A scatterplot of the SUCRA values from the
 #'   network meta-analysis against the SUCRA values from the network
 #'   meta-regression based on the specified \code{cov_value}. See 'Details'
@@ -98,6 +98,7 @@
 #' @examples
 #' data("nma.baker2009")
 #'
+#' \donttest{
 #' # Read results from 'run_model' (using the default arguments)
 #' res <- readRDS(system.file('extdata/res_baker.rds', package = 'rnmamod'))
 #'
@@ -120,6 +121,7 @@
 #'              compar = "salmeterol",
 #'              cov_value = list(2000, "publication year"),
 #'              drug_names = interv_names)
+#' }
 #'
 #' @export
 metareg_plot <- function(full,
@@ -180,7 +182,6 @@ metareg_plot <- function(full,
     compar
   }
 
-
   covariate <- if (length(unique(reg$covariate)) < 3) {
     unique(reg$covariate)
   } else {
@@ -422,11 +423,11 @@ metareg_plot <- function(full,
 
   # Posterior mean of model assessment measures under NMA
   model_assess_nma <- round(full$model_assessment, 2)
+  n_data <- model_assess_nma$n_data
 
   # Posterior mean of model assessment measures under meta-regression
   model_assess_nmr <- round(reg$model_assessment, 2)
 
-
   # The 95% CrIs of the between-trial standard deviation under both models
   if (model == "RE") {
     cri_tau_nma <- paste0("(", tau_nma[, 3], ",", " ", tau_nma[, 7], ")")
@@ -437,8 +438,8 @@ metareg_plot <- function(full,
   if (model == "RE") {
     table_model_assess <- data.frame(c("Network meta-analysis",
                                        "Meta-regression"),
-                                     rbind(model_assess_nma[c(1, 3, 2)],
-                                           model_assess_nmr[c(1, 3, 2)]),
+                                     rbind(model_assess_nma,
+                                           cbind(model_assess_nmr, n_data)),
                                      rbind(cbind(tau_nma[, 5],
                                                  tau_nma[, 2],
                                                  cri_tau_nma),
@@ -446,15 +447,17 @@ metareg_plot <- function(full,
                                                  tau_nmr[, 2],
                                                  cri_tau_nmr)))
     colnames(table_model_assess) <- c("Analysis",
-                                      "DIC", "Mean deviance", "pD",
+                                      "DIC", "pD", "Mean deviance",
+                                      "data points",
                                       "Median tau", "SD tau", "95% CrI tau")
   } else {
     table_model_assess <- data.frame(c("Network meta-analysis",
                                        "Meta-regression"),
-                                     rbind(model_assess_nma[c(1, 3, 2)],
-                                           model_assess_nmr[c(1, 3, 2)]))
+                                     rbind(model_assess_nma,
+                                           cbind(model_assess_nmr, n_data)))
     colnames(table_model_assess) <- c("Analysis",
-                                      "DIC", "Mean deviance", "pD")
+                                      "DIC", "Mean deviance", "pD",
+                                      "data points")
   }
   message(ifelse(model_assess_nma[1] - model_assess_nmr[1] > 5,
                  "NMR preferred when accounting for model fit and complexity",
@@ -463,7 +466,6 @@ metareg_plot <- function(full,
                    "NMA preferred when accounting for model fit and complexity",
                         "There is little to choose between the two models")))
 
-
   # Tabulate results on comparisons with the reference (both models)
   if (model == "RE") {
     est_both_models <- na.omit(data.frame(drug_names_sorted,
@@ -548,7 +550,7 @@ metareg_plot <- function(full,
            knitr::kable(reg_coeff,
                         caption =
                           paste("Estimation of regression coefficient(s)")),
-         interval_plot = suppressWarnings(ggarrange(forest_plots)),
+         interval_plot = suppressWarnings(forest_plots),
          sucra_scatterplot = sucra_scatterplot)
   } else {
     list(table_estimates =
