@@ -71,6 +71,9 @@
 #'   interventions in the trial.
 #'
 #'   Furthermore, the output includes the following elements:
+#'   \item{abs_risk}{The adjusted absolute risks for each intervention. This
+#'   appears only when \code{measure = "OR"}, \code{measure = "RR"}, or
+#'   \code{measure = "RD"}.}
 #'   \item{leverage_o}{The leverage for the observed outcome at each trial-arm.}
 #'   \item{sign_dev_o}{The sign of the difference between observed and fitted
 #'   outcome at each trial-arm.}
@@ -200,6 +203,22 @@ run_metareg <- function(full,
   } else {
     covar_assumption
   }
+  ref_base <- if (is.element(measure, c("OR", "RR", "RD")) &
+                  missing(base_risk)) {
+    base_risk <-
+      describe_network(data = data,
+                       drug_names = 1:item$nt,
+                       measure = measure)$table_interventions[ref, 7]/100
+    rep(log(base_risk / (1 - base_risk)), 2)
+  } else if (is.element(measure, c("OR", "RR", "RD"))) {
+    baseline_model(base_risk,
+                   n_chains,
+                   n_iter,
+                   n_burnin,
+                   n_thin)$ref_base
+  } else if (!is.element(measure, c("OR", "RR", "RD"))) {
+    NA
+  }
   n_chains <- if (missing(n_chains)) {
     2
   } else if (n_chains < 1) {
@@ -241,10 +260,12 @@ run_metareg <- function(full,
                    "indic" = indic,
                    "D" = D)
 
-  data_jag <- if (is.element(measure, c("MD", "SMD", "ROM"))) {
-    append(data_jag, list("y.o" = item$y0, "se.o" = item$se0))
-  } else if (!is.element(measure, c("MD", "SMD", "ROM"))) {
-    append(data_jag, list("r" = item$r, "base_risk" = base_risk))
+  data_jag <- if (!is.element(measure, c("OR", "RR", "RD"))) {
+    append(data_jag, list("y.o" = item$y0,
+                          "se.o" = item$se0))
+  } else if (is.element(measure, c("OR", "RR", "RD"))) {
+    append(data_jag, list("r" = item$r,
+                          "ref_base" = ref_base))
   }
 
   data_jag <- if (length(unique(covariate)) > 2) {
@@ -303,6 +324,12 @@ run_metareg <- function(full,
                            c("EM.pred", "tau", "delta"))]
   }
 
+  param_jags <- if (is.element(measure, c("OR", "RR", "RD"))) {
+    append(param_jags, "abs_risk")
+  } else {
+    param_jags
+  }
+
   # Run the Bayesian analysis
   jagsfit <- jags(data = data_jag,
                   parameters.to.save = param_jags,
@@ -324,6 +351,9 @@ run_metareg <- function(full,
   # Predictive effects of all unique pairwise comparisons
   EM_pred <- t(get_results %>% dplyr::select(starts_with("EM.pred[")))
 
+  # Unique absolute risks for all interventions (only binary data)
+  abs_risk <- t(get_results %>% dplyr::select(starts_with("abs_risk[")))
+
   # Between-trial standard deviation
   tau <- t(get_results %>% dplyr::select(starts_with("tau")))
 
@@ -347,14 +377,6 @@ run_metareg <- function(full,
     starts_with("effectiveness")))
 
   # Estimated missingness parameter
-  #phi <- if (length(unique(na.omit(unlist(item$m)))) > 1) {
-  #  t(get_results %>% dplyr::select(starts_with("phi") |
-  #                                   starts_with("mean.phi") |
-  #                                   starts_with("mean.phi[") |
-  #                                   starts_with("phi[")))
-  #} else {
-  #  NULL
-  #}
   phi <- if (min(na.omit(unlist(item$I))) == 1 &
              max(na.omit(unlist(item$I))) == 1) {
     t(get_results %>% dplyr::select(starts_with("phi") |
@@ -397,7 +419,7 @@ run_metareg <- function(full,
       as.vector(na.omit(melt(item$se0)[, 2]))
       })
 
-    # Deviance at the posterior mean of the fitted mean outcome
+    # Deviance contribution at the posterior mean of the fitted mean outcome
     dev_post_o <- (y0_new -
                      as.vector(hat_par[, 1])) *
       (y0_new - as.vector(hat_par[, 1])) * (1 / se0_new^2)
@@ -414,7 +436,7 @@ run_metareg <- function(full,
     r0 <- ifelse(r_new == 0, r_new + 0.01,
                  ifelse(r_new == obs, r_new - 0.01, r_new))
 
-    # Deviance at the posterior mean of the fitted response
+    # Deviance contribution at the posterior mean of the fitted response
     dev_post_o <- 2 * (r0 * (log(r0) -
                                log(as.vector(hat_par[, 1]))) +
                          (obs - r0) * (log(obs - r0) -
@@ -424,7 +446,7 @@ run_metareg <- function(full,
     sign_dev_o <- sign(r0 - as.vector(hat_par[, 1]))
   }
 
-  # Obtain the leverage for observed and missing outcomes
+  # Obtain the leverage for observed outcomes
   leverage_o <- as.vector(dev_o[, 1]) - dev_post_o
 
   # Number of effective parameters
@@ -461,7 +483,8 @@ run_metareg <- function(full,
                        n_iter = n_iter,
                        n_burnin = n_burnin,
                        n_thin = n_thin,
-                       type = "nmr")
+                       type = "nmr",
+                       abs_risk = abs_risk)
     nma_results <- append(ma_results, list(SUCRA = SUCRA,
                                            effectiveness = effectiveness,
                                            D = full$D))
@@ -485,7 +508,8 @@ run_metareg <- function(full,
                        n_iter = n_iter,
                        n_burnin = n_burnin,
                        n_thin = n_thin,
-                       type = "nmr")
+                       type = "nmr",
+                       abs_risk = abs_risk)
     nma_results <- append(ma_results, list(SUCRA = SUCRA,
                                            effectiveness = effectiveness,
                                            D = full$D))
