@@ -53,11 +53,13 @@
 #' @param ref An integer specifying the reference intervention. The number
 #'   should match the intervention identifier under element \strong{t} in
 #'   \code{data} (See 'Format').
-#' @param base_risk A number in the interval (0, 1) that indicates the baseline
-#'   risk for the selected reference intervention. If \code{base_risk} has not
-#'   been defined, the function uses the median event risk for the reference
-#'   intervention as calculated from the corresponding trials in \code{data}.
-#'   This argument is only relevant for binary outcomes.
+#' @param base_risk A scalar, a vector of length three with elements sorted in
+#'   ascending order, or a matrix with two columns and number of rows equal to
+#'   the number of relevant trials. In the case of a scalar or vector, the
+#'   elements should be in the interval (0, 1) (see 'Details'). If
+#'   \code{base_risk} has not been defined, the function uses the median event
+#'   risk for the reference intervention from the corresponding trials in
+#'   \code{data}. This argument is only relevant for a binary outcome.
 #' @param n_chains Positive integer specifying the number of chains for the
 #'   MCMC sampling; an argument of the \code{\link[R2jags:jags]{jags}} function
 #'   of the R-package \href{https://CRAN.R-project.org/package=R2jags}{R2jags}.
@@ -157,9 +159,6 @@
 #'   the number of interventions in the trial.
 #'
 #'   Furthermore, the output includes the following elements:
-#'   \item{abs_risk}{The absolute risks for each intervention. This appears only
-#'   when \code{measure = "OR"}, \code{measure = "RR"}, or
-#'   \code{measure = "RD"}.}
 #'   \item{leverage_o}{The leverage for the observed outcome at each trial-arm.}
 #'   \item{sign_dev_o}{The sign of the difference between observed and fitted
 #'   outcome at each trial-arm.}
@@ -215,16 +214,16 @@
 #'
 #'   To perform a Bayesian pairwise or network meta-analysis, the
 #'   \code{\link{prepare_model}} function is called which contains the WinBUGS
-#'   code as written by Dias et al. (2013) for binomial and normal likelihood to
+#'   code as written by Dias et al. (2013a) for binomial and normal likelihood to
 #'   analyse aggregate binary and continuous outcome data, respectively.
 #'   \code{\link{prepare_model}} uses the consistency model (as described in
 #'   Lu and Ades (2006)) to estimate all possible comparisons in the network.
 #'   It also accounts for the multi-arm trials by assigning conditional
 #'   univariate normal distributions on the underlying trial-specific effect
 #'   size of comparisons with the baseline arm of the multi-arm trial
-#'   (Dias et al., 2013).
+#'   (Dias et al., 2013a).
 #'
-#'   The code of Dias et al. (2013) has been extended to incorporate the
+#'   The code of Dias et al. (2013a) has been extended to incorporate the
 #'   pattern-mixture model to adjust the underlying outcome in each arm of
 #'   every trial for missing participant outcome data (Spineli et al., 2021;
 #'   Spineli, 2019a; Turner et al., 2015). The assumptions about the
@@ -266,13 +265,34 @@
 #'   determine \code{mean_misspar} and select a proper value for
 #'   \code{var_misspar}.
 #'
+#'   The scalar \code{base_risk} refers to a fixed baseline risk for the
+#'   selected reference intervention (as specified with \code{ref}).
+#'   When \code{base_risk} is a three-element vector, it refers to a random
+#'   baseline risk and the elements should be sorted in ascending order as they
+#'   refer to the lower bound, mean value, and upper bound of the 95\%
+#'   confidence interval for the baseline risk for the selected reference
+#'   intervention. The \code{\link{baseline_model}} function is called to
+#'   calculate the mean and variance of the approximately normal distribution of
+#'   the logit of an event for \code{ref} using these three elements
+#'   (Dias et al., 2018). When \code{base_risk} is a matrix, it refers to the
+#'   predicted baseline risk with first column being the number of events, and
+#'   second column being the sample size of the corresponding trials on the
+#'   selected reference intervention. Then the \code{\link{baseline_model}}
+#'   function is called that contains the WinBUGS code as written by Dias et al.
+#'   (2013b) for the hierarchical baseline model. The posterior mean and
+#'   precision of the predictive distribution of the logit of an event
+#'   for the selected reference intervention are plugged in the WinBUGS code for
+#'   the relative effects model (via the \code{\link{prepare_model}} function).
+#'   The matrix \code{base_risk} should not comprise the trials in \code{data}
+#'   that include the \code{ref}, unless justified (Dias et al., 2018).
+#'
 #'   To obtain unique absolute risks for each intervention, the network
 #'   meta-analysis model has been extended to incorporate the transitive risks
 #'   framework, namely, an intervention has the same absolute risk regardless of
 #'   the comparator intervention(s) in a trial (Spineli et al., 2017).
 #'   The absolute risks are a function of the odds ratio (the \strong{base-case}
 #'   effect measure for a binary outcome) and the selected baseline risk for the
-#'   reference intervention (\code{ref}) (Appendix in Dias et al., 2013).
+#'   reference intervention (\code{ref}) (Appendix in Dias et al., 2013a).
 #'   We advocate using the odds ratio as an effect measure for its desired
 #'   mathematical properties. Then, the relative risk and risk difference can be
 #'   obtained as a function of the absolute risks of the corresponding
@@ -282,7 +302,7 @@
 #'
 #' @author {Loukia M. Spineli}
 #'
-#' @seealso \code{\link{data_preparation}},
+#' @seealso \code{\link{baseline_model}}, \code{\link{data_preparation}},
 #'   \code{\link{heterogeneity_param_prior}}, \code{\link[R2jags:jags]{jags}},
 #'   \code{\link{missingness_param_prior}}, \code{\link{prepare_model}}
 #'
@@ -293,10 +313,17 @@
 #' with non-rheumatic atrial fibrillation.
 #' \emph{Stat Med} 2009;\bold{28}(14):1861--81. doi: 10.1002/sim.3594
 #'
+#' Dias S, Ades AE, Welton NJ, Jansen JP, Sutton AJ. Network Meta-Analysis for
+#' Decision Making. Chichester (UK): Wiley; 2018.
+#'
 #' Dias S, Sutton AJ, Ades AE, Welton NJ. Evidence synthesis for decision
 #' making 2: a generalized linear modeling framework for pairwise and network
 #' meta-analysis of randomized controlled trials. \emph{Med Decis Making}
-#' 2013;\bold{33}(5):607--17. doi: 10.1177/0272989X12458724
+#' 2013a;\bold{33}(5):607--17. doi: 10.1177/0272989X12458724
+#'
+#' Dias S, Welton NJ, Sutton AJ, Ades AE. Evidence synthesis for decision
+#' making 5: the baseline natural history model. \emph{Med Decis Making}
+#' 2013b;\bold{33}(5):657--70. doi: 10.1177/0272989X13485155
 #'
 #' Gelman A, Rubin DB. Inference from iterative simulation using multiple
 #' sequences. \emph{Stat Sci} 1992;\bold{7}(4):457--72.
@@ -375,7 +402,7 @@ run_model <- function(data,
                       var_misspar,
                       D,
                       ref,
-                      base_risk = NULL,
+                      base_risk,
                       n_chains,
                       n_iter,
                       n_burnin,
@@ -410,7 +437,15 @@ run_model <- function(data,
     assumption
   }
   heterog_prior <- heterogeneity_param_prior(measure, model, heter_prior)
-  mean_misspar <- if (missing(assumption)) {
+  mean_misspar <- if (missing(assumption)  & min(na.omit(unlist(item$I))) == 1) {
+    0
+  } else if ((missing(assumption) || assumption != "IND-UNCORR") &
+             (min(na.omit(unlist(item$I))) == 0 &
+              max(na.omit(unlist(item$I))) == 1)) {
+    0
+  } else if ((missing(assumption) || assumption != "IND-UNCORR") &
+             (min(na.omit(unlist(item$I))) == 0 &
+              max(na.omit(unlist(item$I))) == 0)) {
     0
   } else {
     missingness_param_prior(assumption, mean_misspar)
@@ -442,16 +477,21 @@ run_model <- function(data,
   } else {
     ref
   }
-  base_risk <- if (is.element(measure, c("OR", "RR", "RD")) &
-                   missing(base_risk)) {
-    describe_network(data = data,
-                     drug_names = 1:item$nt,
-                     measure = measure)$table_interventions[ref, 7]/100
-  } else if (is.element(measure, c("OR", "RR", "RD")) &
-             (base_risk <= 0 || base_risk >= 1)) {
-    stop("The argument 'base_risk' must be defined in (0, 1).", call. = FALSE)
-  } else {
-    base_risk
+  ref_base <- if (is.element(measure, c("OR", "RR", "RD")) &
+                  missing(base_risk)) {
+    base_risk <-
+      describe_network(data = data,
+                       drug_names = 1:item$nt,
+                       measure = measure)$table_interventions[ref, 7]/100
+    rep(log(base_risk / (1 - base_risk)), 2)
+  } else if (is.element(measure, c("OR", "RR", "RD"))) {
+    baseline_model(base_risk,
+                   n_chains,
+                   n_iter,
+                   n_burnin,
+                   n_thin)$ref_base
+  } else if (!is.element(measure, c("OR", "RR", "RD"))) {
+    NA
   }
   n_chains <- if (missing(n_chains)) {
     2
@@ -509,9 +549,11 @@ run_model <- function(data,
                    "D" = D)
 
   data_jag <- if (is.element(measure, c("MD", "SMD", "ROM"))) {
-    append(data_jag, list("y.o" = item$y0, "se.o" = item$se0))
+    append(data_jag, list("y.o" = item$y0,
+                          "se.o" = item$se0))
   } else if (is.element(measure, c("OR", "RR", "RD"))) {
-    append(data_jag, list("r" = item$r, "base_risk" = base_risk))
+    append(data_jag, list("r" = item$r,
+                          "ref_base" = ref_base))
   }
 
   data_jag <- if (is.element(assumption, "IND-CORR")) {
@@ -662,7 +704,7 @@ run_model <- function(data,
       as.vector(na.omit(melt(item$se0)[, 2]))
       })
 
-    # Deviance at the posterior mean of the fitted mean outcome
+    # Deviance contribution at the posterior mean of the fitted mean outcome
     dev_post_o <- (y0_new -
                      as.vector(hat_par[, 1])) *
       (y0_new - as.vector(hat_par[, 1])) * (1 / se0_new^2)
@@ -679,7 +721,7 @@ run_model <- function(data,
     r0 <- ifelse(r_new == 0, r_new + 0.01,
                  ifelse(r_new == obs, r_new - 0.01, r_new))
 
-    # Deviance at the posterior mean of the fitted response
+    # Deviance contribution at the posterior mean of the fitted response
     dev_post_o <- 2 * (r0 * (log(r0) -
                                log(as.vector(hat_par[, 1]))) +
                          (obs - r0) * (log(obs - r0) -
@@ -689,6 +731,9 @@ run_model <- function(data,
     sign_dev_o <- sign(r0 - as.vector(hat_par[, 1]))
   }
 
+  # Number of unconstrained data-points
+  n_data <- sum(item$na)
+
   # Obtain the leverage for observed outcomes
   leverage_o <- as.vector(dev_o[, 1]) - dev_post_o
 
@@ -699,8 +744,8 @@ run_model <- function(data,
   DIC <- pD + dev
 
   # A data-frame on the measures of model assessment:
-  # DIC, pD, and total residual deviance
-  model_assessment <- data.frame(DIC, pD, dev)
+  # DIC, pD, total residual deviance, and number of unconstrained data-points
+  model_assessment <- data.frame(DIC, pD, dev, n_data)
 
   # Return a list of results
   results <- list(EM = EM,
@@ -749,8 +794,8 @@ run_model <- function(data,
                                         heter_prior = heterog_prior,
                                         SUCRA = SUCRA,
                                         effectiveness = effectiveness,
-                                        base_risk = base_risk,
-                                        abs_risk = abs_risk))
+                                        abs_risk = abs_risk,
+                                        base_risk = base_risk))
   } else if (model == "RE" & is.element(measure, c("RR", "RD"))) {
     ma_results <- append(results, list(EM_pred = EM_pred,
                                        EM_LOR = EM_LOR,
@@ -776,14 +821,16 @@ run_model <- function(data,
     nma_results <- append(results, list(SUCRA = SUCRA,
                                         effectiveness = effectiveness))
   } else if (model == "FE" & measure == "OR") {
-    ma_results <- append(results, list(abs_risk = abs_risk))
+    ma_results <- append(results, list(abs_risk = abs_risk,
+                                       base_risk = base_risk))
     nma_results <- append(results, list(SUCRA = SUCRA,
                                         effectiveness = effectiveness,
                                         abs_risk = abs_risk,
                                         base_risk = base_risk))
   } else if (model == "FE" & is.element(measure, c("RR", "RD"))) {
     ma_results <- append(results, list(EM_LOR = EM_LOR,
-                                       abs_risk = abs_risk))
+                                       abs_risk = abs_risk,
+                                       base_risk = base_risk))
     nma_results <- append(results, list(EM_LOR = EM_LOR,
                                         SUCRA = SUCRA,
                                         SUCRA_LOR = SUCRA_LOR,
